# Roadmap
- [x] Base Operations:
    - [x] Config
    - [x] Sort by filetype
    - [x] Bulk-move files

- [ ] recover deleted dev branch
    - [x] make config overwrite function
        - [x] extend config with "args"
    - [x] implement flatten
    - interactive apprentice 
        - [x] confirmation question using questionary

    - [x] arbitrary conflict move resolution

    - [ ] nicer readme?



- [ ] Modes:
    - [ ] Apprentice:
        - [x] decent storytelling
        - [x] interactive confirmation based stuff -> handle conflict
        -> fitting the apprentices role as someone needing to be guided
    - [ ] Magician
        - [ ] doing all the stuff the apprentice does but with automatic resolving of issues
    - [ ] Witch
        - [ ]  doing all the stuff the magician does but changing your files in the process

    - [ ] Dragon
        -> levels your house in one breath i.e flattens folders

- "The magic" 
    - [ ] smart unzip
    - [ ] dedupe strategies
        - [x] replace by symlink
        - [x] matching exact contents
        - [ ] diffing contents
        - [ ] intentional duplicate recognition
    - [x] autoremove empty files/semi-empty
        - [ ] semi empty/boilerplate
    - [ ] library collision
    - [x] move conflict resolution modes

- Publish
-> maybe add classifiers?
